from enum import Enum


class MergeType(Enum):
    """enum of merge type"""

    REPLACE = 0
    APPEND = 1
